﻿
----------------------------------------------------------------
-- [v1.01.00] Localized Functions and Tables to speed things up
----------------------------------------------------------------
local _L = nUI_InfoPanel_PallyBuffs_L;

---------------------------------------------------
-- [v1.01.00] Initialise Variables
-- [v1.01.00] Alpha and FontSize Values made global
-- [v1.02.00] GreaterBlessingButtons and BlessingButtons made global
-- [v1.02.01] Added option to not display text in blessing window
---------------------------------------------------
PallyBuffs_Defaults = {};
PallyBuffs_Defaults.MaxRestockQty = 5;
PallyBuffs_Defaults.UpdateInterval = 30;
PallyBuffs_Defaults.FontSize = 14;
PallyBuffs_Defaults.NotAvailableAlpha = 0.1;
PallyBuffs_Defaults.NotIdealAlpha = 0.5;
PallyBuffs_Defaults.AvailableAlpha = 1.0;
PallyBuffs_Defaults.DisplayText = true;

PallyBuffs = {};
PallyBuffs.Class = nil;
PallyBuffs.Frame = nil;
PallyBuffs.LastUpdate = 0;
PallyBuffs.GBlessingButtons = {};
PallyBuffs.BlessingButtons = {};
local GBlessingDB = {};
local BlessingDB = {};
local ReagentDB = {};

---------------------------------------------------
-- [v1.03.00] - Added Reagent Database for flexibility
-- [v1.03.00] - Max Quantity to be set to RestockQty by default
---------------------------------------------------
local function PallyBuffs_InitReagentDB()
	ReagentDB = {};
	table.insert(ReagentDB, { item = 21177, max = PallyBuffs_Defaults.MaxRestockQty, level = 5 } ); -- Symbol of Kings
end
---------------------------------------------------
-- [v1.01.00] Initialise GBlessing Spell Database
---------------------------------------------------
local function PallyBuffs_InitGBlessingDB()
	GreaterBlessingDB = {};
	table.insert(GBlessingDB, { quest = false, spell = 48934, faction = _L["ALLIANCE"] } );
	table.insert(GBlessingDB, { quest = false, spell = 48934, faction = _L["HORDE"] } );
	table.insert(GBlessingDB, { quest = false, spell = 25894, faction = _L["ALLIANCE"] } );
	table.insert(GBlessingDB, { quest = false, spell = 25894, faction = _L["HORDE"] } );
	table.insert(GBlessingDB, { quest = false, spell = 25898, faction = _L["ALLIANCE"] } );
	table.insert(GBlessingDB, { quest = false, spell = 25898, faction = _L["HORDE"] } );
	table.insert(GBlessingDB, { quest = false, spell = 25899, faction = _L["ALLIANCE"] } );
	table.insert(GBlessingDB, { quest = false, spell = 25899, faction = _L["HORDE"] } );
end

---------------------------------------------------
-- [v1.01.00] Initialise Blessing Spell Deatabase
---------------------------------------------------
local function PallyBuffs_InitBlessingDB()	
	BlessingDB = {};
	table.insert(BlessingDB, { quest = false, spell = 48932, faction = _L["ALLIANCE"] } );
	table.insert(BlessingDB, { quest = false, spell = 48932, faction = _L["HORDE"] } );
	table.insert(BlessingDB, { quest = false, spell = 48936, faction = _L["ALLIANCE"] } );
	table.insert(BlessingDB, { quest = false, spell = 48936, faction = _L["HORDE"] } );
	table.insert(BlessingDB, { quest = false, spell = 20217, faction = _L["ALLIANCE"] } );
	table.insert(BlessingDB, { quest = false, spell = 20217, faction = _L["HORDE"] } );
	table.insert(BlessingDB, { quest = false, spell = 67480, faction = _L["ALLIANCE"] } );
	table.insert(BlessingDB, { quest = false, spell = 67480, faction = _L["HORDE"] } );
    table.insert(BlessingDB, { quest = true, spell = 48950, faction = _L["ALLIANCE"] } );
	table.insert(BlessingDB, { quest = true, spell = 48950, faction = _L["HORDE"] } );
end

------------------------------------
-- [v1.01.00] Create a Secure Button
-- [v1.01.01] Only update cooldown if one exists
-- [v1.01.01] Validate Reagent Test before Cooldown Test for availability tooltip.
-- [v1.02.00] Removed cooldown count from tooltip
------------------------------------
local function PallyBuffs_CreateSecureSpellButton(spellID, reagentID, level, quest)
	local SpellName, _, SpellIcon = GetSpellInfo(spellID);
	local Available = ( GetSpellInfo(SpellName) ~= nil );
	local ButtonName = "P_" .. spellID;
	local TextureName = ButtonName .. "_Texture";
	
	-- Show a tooltip for the GBlessing button
	local function ShowTooltip(self)
		local Available = ( GetSpellInfo(SpellName) ~= nil );
		local TimeNow = GetTime();
		local CooldownStart, CooldownDuration, CooldownEnabled = GetSpellCooldown(SpellName);
		local CooldownCounter = 0;
		if ( CooldownEnabled ) then	CooldownCounter = CooldownDuration - (TimeNow - CooldownStart); end
		CooldownCounter = math.floor(CooldownCounter);
		local reagentCount = GetItemCount(reagentID);
		GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
		GameTooltip:SetText(SpellName, 1.0, 1.0, 0.0 );
		if ( quest ) then GameTooltip:AddLine(_L["ATTAINED_VIA_QUEST"], 1.0,1.0,1.0); end
		if ( not Available ) then
			GameTooltip:AddLine(_L["UNKNOWN"],1.0);
		elseif ( reagentCount < 1 ) then
			GameTooltip:AddLine(_L["OUT_OF_REAGENTS"], 1.0);
		elseif ( CooldownDuration == 0 ) then
			GameTooltip:AddLine(_L["AVAILABLE"], 1.0,1.0);
		elseif ( CooldownEnabled and CooldownDuration ~= 0) then
			GameTooltip:AddLine(_L["ON_COOLDOWN"], 1.0,1.0,1.0);
		end
		GameTooltip:Show();		
	end
	
    	-- Show a tooltip for the Blessing button
	local function ShowTooltip(self)
		local Available = ( GetSpellInfo(SpellName) ~= nil );
		local TimeNow = GetTime();
		local CooldownStart, CooldownDuration, CooldownEnabled = GetSpellCooldown(SpellName);
		local CooldownCounter = 0;
		if ( CooldownEnabled ) then	CooldownCounter = CooldownDuration - (TimeNow - CooldownStart); end
		CooldownCounter = math.floor(CooldownCounter);
		local reagentCount = GetItemCount(reagentID);
		GameTooltip:SetOwner(self, "ANCHOR_CURSOR");
		GameTooltip:SetText(SpellName, 1.0, 1.0, 0.0 );
		if ( quest ) then GameTooltip:AddLine(_L["ATTAINED_VIA_QUEST"], 1.0,1.0,1.0); end
		if ( not Available ) then
			GameTooltip:AddLine(_L["UNKNOWN"],1.0);
		elseif ( CooldownDuration == 0 ) then
			GameTooltip:AddLine(_L["AVAILABLE"], 1.0,1.0);
		elseif ( CooldownEnabled and CooldownDuration ~= 0) then
			GameTooltip:AddLine(_L["ON_COOLDOWN"], 1.0,1.0,1.0);
		end
		GameTooltip:Show();		
	end
	
	-- Hide the buttons tooltip
	local function HideTooltip(self)
		GameTooltip:Hide();
	end
	
	-- Update the cooldown counter
	local function UpdateCooldown(self)
		local TimeNow = GetTime();
		local CooldownStart, CooldownDuration, CooldownEnabled = GetSpellCooldown(SpellName);
		if ( not CooldownEnabled ) then return; end
		if ( CooldownDuration == 0 ) then return; end	
		local DiffTime = TimeNow - CooldownStart;
		local CooldownCounter = CooldownDuration - DiffTime;
		CooldownCounter = math.floor(CooldownCounter);
		if ( CooldownCounter > 0 ) then	
			self.Text:SetText(CooldownCounter);	
		else
			self.Text:SetText("");	
		end
	end
	-- Hide the buttons tooltip
	local function HideTooltip(self)
		GameTooltip:Hide();
	end
	
	-- Update the cooldown counter
	local function UpdateCooldown(self)
		local TimeNow = GetTime();
		local CooldownStart, CooldownDuration, CooldownEnabled = GetSpellCooldown(SpellName);
		if ( not CooldownEnabled ) then return; end
		if ( CooldownDuration == 0 ) then return; end	
		local DiffTime = TimeNow - CooldownStart;
		local CooldownCounter = CooldownDuration - DiffTime;
		CooldownCounter = math.floor(CooldownCounter);
		if ( CooldownCounter > 0 ) then	
			self.Text:SetText(CooldownCounter);	
		else
			self.Text:SetText("");	
		end
	end
	
	-- Create the button and its children and attributes
	local Button = CreateFrame("Button", ButtonName, UIParent,"ActionButtonTemplate,SecureActionButtonTemplate");			
	Button:SetWidth(36);
	Button:SetHeight(36);			
	local texture = Button:CreateTexture(TextureName,"OVERLAY");
	texture:SetAllPoints(Button);
	texture:SetTexture(SpellIcon);
	Button:SetNormalTexture("Interface\\Buttons\\UI-Quickslot2");
	Button:SetHighlightTexture("Interface\\Buttons\\ButtonHilight-Square", add);
	Button:SetPushedTexture("Interface\\Buttons\\UI-Quickslot-Depress");
	if ( not Available ) then 
		Button:SetAlpha(PallyBuffs_Defaults.NotAvailableAlpha); 
	else
		Button:SetAlpha(PallyBuffs_Defaults.AvailableAlpha);
	end
	Button:SetAttribute("type","spell");
	Button:SetAttribute("spell",SpellName);
	Button:SetScript("OnEnter",ShowTooltip);
	Button:SetScript("OnLeave",HideTooltip);
	
	-- Create the Cooldown frame to display the Cooldown Counter
	Button.Cooldown = CreateFrame("Frame", ButtonName.."_Cooldown", Button);
	Button.Cooldown:SetAllPoints(Button);
	Button.Cooldown.Text = Button.Cooldown:CreateFontString(ButtonName.."_Cooldown_Text", 'ARTWORK', "GameFontNormal");
	local Path, Size, Flags = Button.Cooldown.Text:GetFont()
	Button.Cooldown.Text:SetFont(Path,PallyBuffs_Defaults.FontSize,Flags);
	Button.Cooldown.Text:SetAllPoints(Button.Cooldown);
	Button.Cooldown.Text:SetJustifyH( "CENTER" );
	Button.Cooldown.Text:SetJustifyV( "MIDDLE" );
	Button.Cooldown.Text:SetTextColor( 1, 1, 0, 1 );
	Button.Cooldown.Text:SetText("");  
	Button.Cooldown:SetScript("OnUpdate",UpdateCooldown);
		
	return Button;
end

---------------------------------------------------
-- [v1.01.00] Initialise the Buttons
-- [v1.03.00] Use ReagentDB itemID
---------------------------------------------------
local function PallyBuffs_InitButtons(parent)
	PallyBuffs.GBlessingButtons = {};
	PallyBuffs.BlessingButtons = {};
	local Faction = string.lower(UnitFactionGroup("player"));

	-- First the GBlessing
	for i,v in pairs(GBlessingDB) do
		if ( string.find(v.faction,Faction) ) then
			local Button = PallyBuffs_CreateSecureSpellButton(v.spell,ReagentDB[1].item, v.level, v.quest);
			Button:SetParent(parent);
			table.insert(PallyBuffs.GBlessingButtons,Button);
		end
	end
	
	-- Now the Blessing
	for i,v in pairs(BlessingDB) do
		if ( string.find(v.faction,Faction) ) then
			local Button = PallyBuffs_CreateSecureSpellButton(v.spell, v.level, v.quest);
			Button:SetParent(parent);
			table.insert(PallyBuffs.BlessingButtons,Button);
		end
	end
end

---------------------------------------------------------------------------
-- [v1.01.00] Validate the Spell in case you cast the wrong one by mistake
-- [v1.01.02] Take into account casts that do not have spell names, links and ids
---------------------------------------------------------------------------
local function PallyBuffs_ValidateSpell(StartStop, Caster, SpellName, SpellRank)

	
	-- Not a spell then don't proceed
	if ( not SpellName ) then return false; end
	
	local SpellID = nil;
	local SpellLink = GetSpellLink(SpellName,"");

	-- No spell link to discern ID from so not a true spell
	if ( not SpellLink ) then return false; end	
	
	local Found, _, SpellString = string.find(SpellLink, "^|c%x+|H(.+)|h%[.*%]");
	if ( Found ) then _, SpellID = strsplit(":", SpellString); end
	SpellID = tonumber(SpellID);
	
	-- SpellID cannot be found so unable to validate spell
	if ( not SpellID ) then return false; end

	local GBlessingSpell = false;
	local BlessingSpell = false;
	for i,v in pairs(GBlessingDB) do
		v.spell = tonumber(v.spell);
		if ( v.spell == SpellID ) then GBlessingSpell = true; break; end
	end
	for i,v in pairs(BlessingDB) do
		v.spell = tonumber(v.spell);
		if ( v.spell == SpellID ) then BlessingSpell = true; break; end
	end	
	
	if ( StartStop == "STOP" ) then 
		if (GBlessingSpell or BlessingSpell) then return true; end
		return false;
	end
	
	if ( GetNumRaidMembers() > 5 ) then
		if ( GBlessingSpell ) then UIErrorsFrame:AddMessage(_L["RAID_BLESSING"], 1.0,1.0,0.0); end
	elseif ( GetNumPartyMembers() > 0 ) then
		if ( GBlessingSpell ) then UIErrorsFrame:AddMessage(_L["PARTY_BLESSING"], 1.0,1.0,0.0); end
	else
		if ( BlessingSpell ) then UIErrorsFrame:AddMessage(_L["SOLO_BLESSING"], 1.0,1.0,0.0); end
	end
		
	if (GBlessingSpell or BlessingSpell) then return true; end
	return false;
end

---------------------------------------------------
-- [v1.01.00] Update the Frame with current information
-- [v1.02.00] Use Not Available alpha if no more reagents
-- [v1.02.01] Added option to not display text in Blessing window
-- [v1.02.02] Added ReagentName variable for those that don't know about it yet
-- [v1.03.00] Use ReagentDB data
---------------------------------------------------
local function PallyBuffs_UpdateFrame(ForceUpdate)

	-- We may want to force the update so only test interval if we are using OnUpdate function
	local TimeNow = GetTime();
	if ( not ForceUpdate ) then
		if TimeNow < ( PallyBuffs.LastUpdate + PallyBuffs_Defaults.UpdateInterval ) then return; 	end
	end
	PallyBuffs.LastUpdate = TimeNow;

	local Solo = false;
	local IsInRaid = false;
	local IsInParty = false;
	if ( GetNumRaidMembers() > 5) then 
		IsInRaid = true; 
	elseif ( GetNumPartyMembers() > 0 ) then 
		IsInParty = true; 
	else
		Solo = true;
	end
	
	-- First the GBlessing Buttons	
	for i,v in pairs(PallyBuffs.GBlessingButtons) do
		local reagentName = select(2,GetItemInfo(ReagentDB[1].item)) or nil;
		local reagentCount = GetItemCount(ReagentDB[1].item) or 0;
		local spellName = v:GetAttribute("spell");
		local Available = ( GetSpellInfo(spellName) ~= nil );
		if ( not Available or reagentCount == 0 ) then 
			v:SetAlpha(PallyBuffs_Defaults.NotAvailableAlpha); 
		else
			if (Solo) then 
				v:SetAlpha(PallyBuffs_Defaults.NotIdealAlpha); 
			else
				v:SetAlpha(PallyBuffs_Defaults.AvailableAlpha);
			end
		end
		if ( PallyBuffs_Defaults.DisplayText and reagentName ) then
			v:GetParent().GBlessingCount:SetText(reagentName .. " : " .. reagentCount);  
			v:GetParent().GBlessingTitle:SetText(_L["GREATER BLESSINGS"]);  
		else
			v:GetParent().GBlessingCount:SetText("");
			v:GetParent().GBlessingTitle:SetText("");
		end
	    local Path, Size, Flags = v.Cooldown.Text:GetFont()
		v.Cooldown.Text:SetFont(Path,PallyBuffs_Defaults.FontSize,Flags);
		v.Cooldown.Text:SetAlpha(1.0);
	end

	-- Then the Blessing Buttons
	for i,v in pairs(PallyBuffs.BlessingButtons) do
		local spellName = v:GetAttribute("spell");
		local Available = ( GetSpellInfo(spellName) ~= nil );
		if ( not Available or reagentCount == 0 ) then 
			v:SetAlpha(PallyBuffs_Defaults.NotAvailableAlpha); 
		else
			if (IsInRaid) then 
				v:SetAlpha(PallyBuffs_Defaults.NotIdealAlpha); 
			elseif (IsInParty) then 
				v:SetAlpha(PallyBuffs_Defaults.NotIdealAlpha);
			else
				v:SetAlpha(PallyBuffs_Defaults.AvailableAlpha);
			end
		end
		if ( PallyBuffs_Defaults.DisplayText and reagentName) then
			v:GetParent().BlessingTitle:SetText(_L["BLESSINGS"]);  
			v:GetParent().BlessingCount:SetText(reagentName .. " : " .. reagentCount);  
		else
			v:GetParent().BlessingCount:SetText("");
			v:GetParent().BlessingTitle:SetText("");
		end
	    local Path, Size, Flags = v.Cooldown.Text:GetFont()
		v.Cooldown.Text:SetFont(Path,PallyBuffs_Defaults.FontSize,Flags);
		v.Cooldown.Text:SetAlpha(1.0);
	end
	
end

---------------------------------------------------
-- [v1.01.00] Initialise the whole Frame
-- [v1.02.00] Removed Anchoring here while in nUI panel
-- [v1.02.01] Added option to not display text in blessing window
---------------------------------------------------
local function PallyBuffs_InitFrame()

	-- Create the Frame itself
	local frame = CreateFrame("Frame","PallyBuffs_Frame",UIParent);
    frame:SetWidth(250);        
    frame:SetHeight(100);
    frame:SetAlpha(1.0);        
    frame:SetClampedToScreen(true);
	frame:SetPoint("CENTER",UIParent,"CENTER",0,0);
    
    -- Create the GBlessing Title 
    frame.GBlessingTitle = frame:CreateFontString("PallyBuffs_Frame_GBlessingTitle", 'ARTWORK', "GameFontNormal");
	frame.GBlessingTitle:SetPoint("TOPLEFT",frame,"TOPLEFT",0,-5);	
	frame.GBlessingTitle:SetText("");
	
	-- Create the GBlessing Reagent Count 
    frame.GBlessingCount = frame:CreateFontString("PallyBuffs_Frame_GBlessingCount", 'ARTWORK', "GameFontNormal");
	frame.GBlessingCount:SetPoint("TOPRIGHT",frame,"TOPRIGHT",0,-5);
	frame.GBlessingCount:SetText("");  
	
	-- Create the Blessing Title
    frame.BlessingTitle = frame:CreateFontString("PallyBuffs_Frame_BlessingTitle", 'ARTWORK', "GameFontNormal");
	frame.BlessingTitle:SetPoint("TOPLEFT",frame,"TOPLEFT",0,-90);
	frame.BlessingTitle:SetText("");

	-- Create the Blessing Reagent Count
    frame.BlessingCount = frame:CreateFontString("PallyBuffs_Frame_TeleportCount", 'ARTWORK', "GameFontNormal");
	frame.BlessingCount:SetPoint("TOPRIGHT",frame,"TOPRIGHT",0,-90);
	frame.BlessingCount:SetText("");  
	
	-- Create the Buttons Table based on player faction
	PallyBuffs_InitButtons(frame);

	-- Assign the OnUpdate Routine to keep the Frame updated every second
	frame:SetScript("OnUpdate",PallyBuffs_UpdateFrame);
	
	-- Return this frame for use by the addon
	return frame;

end

-----------------------------------------------------------------------
-- [v1.01.00] Check if we are at a reagent vendor and ask if to restock
-- [v1.01.01] Only restock Symbol of Kings if over level 52
-- [v1.01.01] Only restock Symbol of Divinity if over level 30
-- [v1.03.01] Use ReagentDB to handle restocking for customization
-----------------------------------------------------------------------
local function PallyBuffs_ReagentRestock(Confirmed)

	local ReagentVendor	= false;
	local ReagentsLow	= false;
	local RestockList	= {};
	
	local PlayerLevel = UnitLevel("player");
	 

	-- Create a list of Reagents to Restock	
	-- for itemID = 21177, 1 do
	for i,reagent in pairs(ReagentDB) do
		local name = GetItemInfo(reagent.item);
		local qty = GetItemCount(reagent.item);
		RestockList[name] = false;
		if ( qty < reagent.max ) then 
			ReagentsLow = true;
			--if ( PlayerLevel > (reagent.level-1 and itemID == 21177 )then
			if ( PlayerLevel > ( reagent.level - 1 ) ) then
				RestockList[name] = true;
			end
		end
	end

	-- If we have (PallyBuffs_Defaults.MaxRestockQty) of each reagent then no need to continue
	if ( not ReagentsLow ) then return; end
	
	-- Check to see if this is a reagent vendor
	-- If it is and we have confirmed restocking then buy the reagents
	ReagentVendor = false;
	for i = 1, GetMerchantNumItems(), 1 do
		local name, _, price, quantity = GetMerchantItemInfo(i);
		if ( RestockList[name] ) then
			ReagentVendor = true;
			if ( Confirmed ) then
				local count	= GetItemCount(name);
				local restock = 0;	
				for j,reagent in pairs(ReagentDB) do
					local dbName = GetItemInfo(reagent.item);
					if ( dbName == name ) then
						if ( count < reagent.max ) then
							restock = reagent.max - count;
							BuyMerchantItem(i,restock);
							break;
						end
					end
				end
			else
				break;
			end
		end
	end

	-- If this is a reagent vendor then pop up the question to restock
	if ( ReagentVendor ) then
		StaticPopup_Show("RESTOCK_REAGENTS");
	end
	
end

-----------------------------------------------------------------------
-- [v1.01.00] Setup for the reagent restocking dialog
-----------------------------------------------------------------------
StaticPopupDialogs["RESTOCK_REAGENTS"] = {
	text = _L["RESTOCK_REAGENTS"],
	button1 = _L["YES"],
	button2 = _L["NO"],
	OnAccept = function() PallyBuffs_ReagentRestock(true); end,
	timeout = 0,
	whileDead = 0,
	hideOnEscape = 1
};

-----------------------------------------------------------------------
-- [v1.01.00] OnEvent function for this addon
-----------------------------------------------------------------------
local function PallyBuffs_OnEvent()
	if event == "LEARNED_SPELL_IN_TAB" then
		PallyBuffs_UpdateFrame(true);
	elseif event == "PLAYER_ENTERING_WORLD" then
		PallyBuffs_UpdateFrame(true);
	elseif event == "UNIT_SPELLCAST_START" then		
		if ( PallyBuffs_ValidateSpell("START", arg1, arg2, arg3) ) then 
			PallyBuffs_UpdateFrame(true);
		end
	elseif event == "UNIT_SPELLCAST_STOP" then
		if ( PallyBuffs_ValidateSpell("STOP", arg1, arg2, arg3) ) then
			PallyBuffs_UpdateFrame(true);
		end
	elseif event == "MERCHANT_SHOW" then
		PallyBuffs_ReagentRestock();
		PallyBuffs_UpdateFrame(true);
	elseif event == "MERCHANT_CLOSED" then
		StaticPopup_Hide("RESTOCK_REAGENTS");
		PallyBuffs_UpdateFrame(true);
	end
end

-----------------------------------------------------------------------------
-- [v1.02.00] Check Slash Commands
-----------------------------------------------------------------------------
local function PallyBuffs_SlashCommands(msg)
        msg = string.lower(msg);
		local args = {};
		for word in string.gmatch(msg,"[^%s]+") do
			table.insert(args,word);
		end
		DefaultsChanged = false;
		if ( args[1] == "notext" ) then
			PallyBuffs_Defaults.DisplayText = not PallyBuffs_Defaults.DisplayText;		
			DefaultsChanged = true;
        elseif ( args[1] == "restock" ) then
			if ( args[2] and tonumber(args[2]) >= 0 and tonumber(args[2]) <= 100) then
				PallyBuffs_Defaults.MaxRestockQty = tonumber(args[2]);
			else
				PallyBuffs_Defaults.MaxRestockQty = 100;
			end
			DefaultsChanged = true;
		elseif ( args[1] == "autoupdate" ) then
			if ( args[2] and tonumber(args[2]) >= 0 and tonumber(args[2]) <= 60) then
				PallyBuffs_Defaults.UpdateInterval = tonumber(args[2]);
			else
				PallyBuffs_Defaults.UpdateInterval = 30;
			end
			DefaultsChanged = true;
		elseif ( args[1] == "fontsize" ) then
			if ( args[2] and tonumber(args[2]) >= 8 and tonumber(args[2]) <= 20) then
				PallyBuffs_Defaults.FontSize = tonumber(args[2]);
			else
				PallyBuffs_Defaults.FontSize = 14;			
			end
			DefaultsChanged = true;
		elseif (args[1] == "alpha-na" ) then
			if ( args[2] and tonumber(args[2]) >= 0.0 and tonumber(args[2]) < 1.0 ) then
				PallyBuffs_Defaults.NotAvailableAlpha = tonumber(args[2]);
			else
				PallyBuffs_Defaults.NotAvailableAlpha = 0.1;
			end
			DefaultsChanged = true;
		elseif (args[1] == "alpha-ni" ) then
			if ( args[2] and tonumber(args[2]) >= 0.0 and tonumber(args[2]) <= 1.0 ) then
				PallyBuffs_Defaults.NotIdealAlpha = tonumber(args[2]);
			else
				PallyBuffs_Defaults.NotIdealAlpha = 0.5;
			end
			DefaultsChanged = true;
		elseif (args[1] == "alpha-ia" ) then
			if ( args[2] and tonumber(args[2]) >= 0.0 and tonumber(args[2]) <= 1.0 ) then
				PallyBuffs_Defaults.AvailableAlpha = tonumber(args[2]);
			else
				PallyBuffs_Defaults.AvailableAlpha = 1.0;
			end
			DefaultsChanged = true;
		else
			DEFAULT_CHAT_FRAME:AddMessage(_L["SLASH_COMMAND_LIST"] .. "( /pallybuffs , /pb)" );
			DEFAULT_CHAT_FRAME:AddMessage(_L["SLASH_RESET"]);
			DEFAULT_CHAT_FRAME:AddMessage("notext " .. _L["NOTEXT_SLASH"]);
			DEFAULT_CHAT_FRAME:AddMessage("restock x    ( x >= 0   , x <= 100, 10  ) - " .. _L["RESTOCK_SLASH"] );
			DEFAULT_CHAT_FRAME:AddMessage("autoupdate x ( x >= 0   , x <= 60 , 30  ) - " .. _L["UPDATE_SLASH"] );
			DEFAULT_CHAT_FRAME:AddMessage("fontsize x   ( x >= 8   , x <= 20 , 14  ) - " .. _L["FONT_SLASH"] );
			DEFAULT_CHAT_FRAME:AddMessage("alpha-na x   ( x >= 0.0 , x <= 1.0, 0.1 ) - " .. _L["ALPHANA_SLASH"] );
			DEFAULT_CHAT_FRAME:AddMessage("alpha-ni x   ( x >= 0.0 , x <= 1.0, 0.5 ) - " .. _L["ALPHANI_SLASH"] );
			DEFAULT_CHAT_FRAME:AddMessage("alpha-ia x   ( x >= 0.0 , x <= 1.0, 1.0 ) - " .. _L["ALPHAIA_SLASH"] );
		end
		if ( DefaultsChanged ) then PallyBuffs_UpdateFrame(true); end
end
-----------------------------------------------------------------------------


-----------------------------------------------------------------------------
-- [v1.02.00] Set Up Slash Commands
-----------------------------------------------------------------------------
local function PallyBuffs_SetUpSlashCommands()
	SLASH_PallyBuffsCmd1 = '/pallybuffs';
	SLASH_PallyBuffsCmd2 = '/pb';
	SlashCmdList['PallyBuffsCmd'] = PallyBuffs_SlashCommands;
end
-----------------------------------------------------------------------------

-----------------------------------------------------------------------
-- [v1.01.00] Create Frame Function called from outside to use this addon
-- [v1.02.00] Added Slash Command functionality
-- [v1.03.01] Added Reagent Database for flexibility
-----------------------------------------------------------------------
function PallyBuffs_CreateFrame()
	local playerClass, englishClass = UnitClass("player");
	PallyBuffs.Frame = nil;
	if ( englishClass == "PALADIN" ) then
		PallyBuffs_InitReagentDB();
		PallyBuffs_InitGBlessingDB();
		PallyBuffs_InitBlessingDB();
		PallyBuffs.Frame = PallyBuffs_InitFrame();
		PallyBuffs.Frame:SetScript( "OnEvent", PallyBuffs_OnEvent );
		PallyBuffs.Frame:RegisterEvent( "LEARNED_SPELL_IN_TAB" );
		PallyBuffs.Frame:RegisterEvent( "PLAYER_ENTERING_WORLD" );
		PallyBuffs.Frame:RegisterEvent( "UNIT_SPELLCAST_START" );
		PallyBuffs.Frame:RegisterEvent( "UNIT_SPELLCAST_STOP" );
		PallyBuffs.Frame:RegisterEvent( "MERCHANT_SHOW" );
		PallyBuffs.Frame:RegisterEvent( "MERCHANT_CLOSED" );
		if ( PallyBuffs.Frame ) then
			PallyBuffs_SetUpSlashCommands();
		end	
	end
end
