﻿---------------------------------------------------
-- [v1.01.00] Make sure we have nUI tables
---------------------------------------------------
if not nUI_InfoPanels then nUI_InfoPanels = {}; end

----------------------------------------------------------------
-- [v1.01.00] Localized Functions and Tables to speed things up
----------------------------------------------------------------
local _L = nUI_InfoPanel_PallyBuffs_L;

---------------------------------------------------
-- [v1.01.00] Allocation of the Window ID (unique)
---------------------------------------------------
nUI_INFOMODE_PALLYBUFFS  = 18;
nUI_INFOPANEL_PALLYBUFFS = "nUI_InfoPanel_PallyBuffs";

---------------------------------------------------
-- [v1.01.00] Set the Default values for the Infopanel
---------------------------------------------------
nUI_InfoPanels[nUI_INFOPANEL_PALLYBUFFS ] =
{	
	enabled   = true,
	desc      = _L["Info Panel Text"],             -- player friendly name/description of the panel
	label     = _L["Info Panel Label"],	       -- label to use on the panel selection button face
	rotation  = nUI_INFOMODE_PALLYBUFFS,           -- index or position this panel appears on/in when clicking the selector button
	full_size = true;                              -- this plugin requires the entire info panel port without the button bag
	
	options  =
	{
		enabled  = true,
	},
};

---------------------------------------------------
-- [v1.01.00] Set Plugin Values
---------------------------------------------------
local plugin    = CreateFrame( "Frame", nUI_INFOPANEL_PALLYBUFFS, nUI_Dashboard.Anchor );
plugin.active   = true;

---------------------------------------------------
-- [v1.01.00] Validate Addon is loaded
---------------------------------------------------
local function onPallyBuffsEvent()
	if event == "VARIABLES_LOADED" then
		PallyBuffs_CreateFrame();
		if ( not PallyBuffs.Frame ) then
			plugin.active = false;
		end
	end	
end

plugin:SetScript( "OnEvent", onPallyBuffsEvent );
plugin:RegisterEvent( "VARIABLES_LOADED" );

---------------------------------------------------
-- [v1.01.00] initPanel routine
---------------------------------------------------
plugin.initPanel = function( container, options )
	plugin.container = container;
	plugin.options   = options;
	if options and options.enabled then
		plugin.setEnabled( true );
	end
end

---------------------------------------------------
-- [v1.01.00] sizeChanged routine
-- [v1.01.03] Changed name of addon frame so as not to clash
-- [v1.02.00] Resize and Reposition according to scale
---------------------------------------------------
plugin.sizeChanged = function( scale, height, width )
	local options  = plugin.options;
	plugin.scale = scale;

	-- Grab addon information and unlock frame for movement
	local PallyBuffsFrame   = plugin.PallyBuffs;
	nUI_Movers:lockFrame( PallyBuffsFrame, false, nil );
	
	-- Resize and Reposition according to scale and size of new container
	PallyBuffsFrame:SetWidth( width ); 
	PallyBuffsFrame:SetHeight( height ); 
	
	-- Center Buttons across the container
	local cellCount = #PallyBuffs.GBlessingButtons;
    local cellWidth = ( width / cellCount );
    local btnSize = 40;
    local btnGap = cellWidth * 0.1;
    local verticalOffsetGBlessing = height / 5; 

    for i=1,cellCount do
        PallyBuffs.GBlessingButtons[i]:SetWidth( btnSize );
        PallyBuffs.GBlessingButtons[i]:SetHeight( btnSize );
    end
    
    local odd = ( cellCount % 2 ) == 1;
    local midwayLeft = nil;
    local midwayRight = nil;
    if ( odd ) then 
		midwayLeft = math.ceil( cellCount / 2 );
	else
		midwayLeft = math.floor( cellCount / 2 );
		midwayRight = midwayLeft + 1;
	end

	-- Reposition GBlessing Buttons and Fontstrings
	if ( not midwayRight ) then
		PallyBuffs.GBlessingButtons[midwayLeft]:SetPoint( "CENTER", plugin.container, "CENTER", btnGap/2, verticalOffsetGBlessing);
	else
	    PallyBuffs.GBlessingButtons[midwayLeft]:SetPoint( "RIGHT", plugin.container, "CENTER", -btnGap/2, verticalOffsetGBlessing );
		PallyBuffs.GBlessingButtons[midwayRight]:SetPoint( "LEFT", plugin.container, "CENTER", btnGap/2, verticalOffsetGBlessing );
	end
	for i = 1, midwayLeft - 1 do	
		PallyBuffs.GBlessingButtons[i]:SetPoint( "RIGHT", PallyBuffs.GBlessingButtons[i+1], "LEFT", -btnGap, 0 );
	end
	for i = midwayLeft + 1, cellCount do	
		PallyBuffs.GBlessingButtons[i]:SetPoint( "LEFT", PallyBuffs.GBlessingButtons[i-1], "RIGHT", btnGap, 0 );
	end
	PallyBuffsFrame.GBlessingTitle:SetPoint( "BOTTOMLEFT", PallyBuffs.GBlessingButtons[1], "TOPLEFT", -btnGap, 0);
	PallyBuffsFrame.GBlessingCount:SetPoint( "BOTTOMRIGHT", PallyBuffs.GBlessingButtons[cellCount], "TOPRIGHT", -btnGap, 0);	
    
    -- Center Buttons across the container
	local cellCount = #PallyBuffs.BlessingButtons;
    local cellWidth = ( width / cellCount );
    local btnSize = 40;
    local btnGap = cellWidth * 0.1; 
    local verticalOffsetBlessing = height / 4;

    for i=1,cellCount do
        PallyBuffs.BlessingButtons[i]:SetWidth( btnSize );
        PallyBuffs.BlessingButtons[i]:SetHeight( btnSize );
    end
    
    local odd = ( cellCount % 2 ) == 1;
    local midwayLeft = nil;
    local midwayRight = nil;
    if ( odd ) then 
		midwayLeft = math.ceil( cellCount / 2 );
	else
		midwayLeft = math.floor( cellCount / 2 );
		midwayRight = midwayLeft + 1;
	end

	-- Reposition Blessing Buttons and Fontstrings
	if ( not midwayRight ) then
		PallyBuffs.BlessingButtons[midwayLeft]:SetPoint( "CENTER", plugin.container, "CENTER", btnGap/2, -verticalOffsetBlessing);
	else
	    PallyBuffs.BlessingButtons[midwayLeft]:SetPoint( "RIGHT", plugin.container, "CENTER", -btnGap/2, -verticalOffsetBlessing );
		PallyBuffs.BlessingButtons[midwayRight]:SetPoint( "LEFT", plugin.container, "CENTER", btnGap/2, -verticalOffsetBlessing );
	end
	for i = 1, midwayLeft - 1 do	
		PallyBuffs.BlessingButtons[i]:SetPoint( "RIGHT", PallyBuffs.BlessingButtons[i+1], "LEFT", -btnGap, 0 );
	end
	for i = midwayLeft + 1, cellCount do	
		PallyBuffs.BlessingButtons[i]:SetPoint( "LEFT", PallyBuffs.BlessingButtons[i-1], "RIGHT", btnGap, 0 );
	end	
	PallyBuffsFrame.BlessingTitle:SetPoint( "BOTTOMLEFT", PallyBuffs.BlessingButtons[1], "TOPLEFT", -btnGap, 0);
	PallyBuffsFrame.BlessingCount:SetPoint( "BOTTOMRIGHT", PallyBuffs.BlessingButtons[cellCount], "TOPRIGHT", -btnGap, 0);
	
	-- Lock addon frame for movement
	nUI_Movers:lockFrame( PallyBuffsFrame, true, nil );
end	

---------------------------------------------------
-- [v1.01.00] Validate Enable Status
---------------------------------------------------
plugin.setEnabled = function( enabled )
	if plugin.enabled ~= enabled then
		plugin.enabled = enabled;
		if not enabled then
			local PallyBuffs = plugin.PallyBuffs;
			if PallyBuffs.saved_parent then
				nUI_Movers:lockFrame( PallyBuffs, false, nil );
				PallyBuffs:SetParent( PallyBuffs.saved_parent );
				PallyBuffs:SetBackdropBorderColor( PallyBuffs.border_color );
				PallyBuffs:SetBackdropColor( PallyBuffs.backdrop_color );
			end
		else
			local PallyBuffs = PallyBuffs.Frame;
			plugin.PallyBuffs = PallyBuffs;
			if not PallyBuffs.saved_parent then
				PallyBuffs.saved_parent   = PallyBuffs:GetParent();
				PallyBuffs.border_color   = PallyBuffs:GetBackdropBorderColor();
				PallyBuffs.backdrop_color = PallyBuffs:GetBackdropColor();
			end
			PallyBuffs:SetParent( plugin.container );
			PallyBuffs:SetPoint( "TOPLEFT", plugin.container, "TOPLEFT", 10, 10 );
			PallyBuffs:SetPoint( "BOTTOMRIGHT", plugin.container, "BOTTOMRIGHT", 0, 0 );
			PallyBuffs:SetFrameStrata( plugin.container:GetFrameStrata() );
			PallyBuffs:SetFrameLevel( plugin.container:GetFrameLevel()+1 );
			PallyBuffs:SetBackdropBorderColor( 0, 0, 0, 0 );
			PallyBuffs:SetBackdropColor( 0, 0, 0, 0 );
			
			nUI_Movers:lockFrame( PallyBuffs, true, nil );
		end				
	end			
end

---------------------------------------------------
-- [v1.01.00] setSelected routine
---------------------------------------------------
plugin.setSelected = function( selected )
	if selected ~= plugin.selected then
		plugin.selected = selected;
		if selected then
		else
		end
	end
end
